4.30. umbra.launcher — Umbra 1.0.4 documentation

### Navigation

- index
- modules |
- next |
- previous |
- Umbra 1.0.4 documentation »
- 4. Api »

# 4.30. umbra.launcher

launcher.py

Platform:
  Windows, Linux, Mac Os X.
Description:
  This module runs the Umbra package `umbra.engine.Umbra` engine class.

Others:

## 4.30.1. Functions

`umbra.launcher.` `main`()

  This definition starts the Application.

  Returns: | Definition success. ( Boolean )

### Navigation

- index
- modules |
- next |
- previous |
- Umbra 1.0.4 documentation »
- 4. Api »